==> batch-sdk-1.18.1-sources.jar: com/batch/android/core/TLSSocketFactory.java <==
package com.batch.android.core;

import android.os.Build;

import java.io.IOException;
import java.net.InetAddress;
import java.net.Socket;
import java.net.UnknownHostException;
import java.security.KeyManagementException;
import java.security.NoSuchAlgorithmException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import javax.net.ssl.SSLContext;
import javax.net.ssl.SSLSocket;
import javax.net.ssl.SSLSocketFactory;

public class TLSSocketFactory extends SSLSocketFactory
{
    private static List<String> enabledProtocols;

    private SSLSocketFactory internalSSLSocketFactory;
    private String[] protocols;

    static {
        enabledProtocols = new ArrayList<>();
        if (Build.VERSION.SDK_INT <= Build.VERSION_CODES.KITKAT_WATCH) {
            enabledProtocols.add("TLSv1");
            enabledProtocols.add("TLSv1.1");
            enabledProtocols.add("TLSv1.2");
        } else if (Build.VERSION.SDK_INT <= Build.VERSION_CODES.P) {
            enabledProtocols.add("TLSv1.2");
        } else {
            enabledProtocols.add("TLSv1.2");
            enabledProtocols.add("TLSv1.3");
        }
    }

    public TLSSocketFactory() throws KeyManagementException, NoSuchAlgorithmException
    {
        SSLContext context = SSLContext.getInstance("TLS");
        context.init(null, null, null);
        internalSSLSocketFactory = context.getSocketFactory();

        List<String> supportedProtocols = Arrays.asList(context.getDefaultSSLParameters().getProtocols());
        List<String> protocols = new ArrayList<>(enabledProtocols);
        protocols.retainAll(supportedProtocols);
        this.protocols = protocols.toArray(new String[0]);
    }

    @Override
    public String[] getDefaultCipherSuites()
    {
        return internalSSLSocketFactory.getDefaultCipherSuites();
    }

    @Override
    public String[] getSupportedCipherSuites()
    {
        return internalSSLSocketFactory.getSupportedCipherSuites();
    }

    @Override
    public Socket createSocket() throws IOException
    {
        return enableTLSOnSocket(internalSSLSocketFactory.createSocket());
    }

    @Override
    public Socket createSocket(Socket s,
                               String host,
                               int port,
                               boolean autoClose) throws IOException
    {
        return enableTLSOnSocket(internalSSLSocketFactory.createSocket(s, host, port, autoClose));
    }

    @Override
    public Socket createSocket(String host, int port) throws IOException, UnknownHostException
    {
        return enableTLSOnSocket(internalSSLSocketFactory.createSocket(host, port));
    }

    @Override
    public Socket createSocket(String host,
                               int port,
                               InetAddress localHost,
                               int localPort) throws IOException, UnknownHostException
    {
        return enableTLSOnSocket(internalSSLSocketFactory.createSocket(host,
                port,
                localHost,
                localPort));
    }

    @Override
    public Socket createSocket(InetAddress host, int port) throws IOException
    {
        return enableTLSOnSocket(internalSSLSocketFactory.createSocket(host, port));
    }

    @Override
    public Socket createSocket(InetAddress address,
                               int port,
                               InetAddress localAddress,
                               int localPort) throws IOException
    {
        return enableTLSOnSocket(internalSSLSocketFactory.createSocket(address,
                port,
                localAddress,
                localPort));
    }

    private Socket enableTLSOnSocket(Socket socket)
    {
        if (( socket instanceof SSLSocket ) && protocols.length > 0) {
            ( (SSLSocket) socket ).setEnabledProtocols(protocols);
        }
        return socket;
    }
}

==> batch-sdk-1.18.3-sources.jar: com/batch/android/core/TLSSocketFactory.java <==
package com.batch.android.core;

import android.os.Build;
import java.io.IOException;
import java.net.InetAddress;
import java.net.Socket;
import java.net.UnknownHostException;
import java.security.KeyManagementException;
import java.security.NoSuchAlgorithmException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.net.ssl.SSLContext;
import javax.net.ssl.SSLSocket;
import javax.net.ssl.SSLSocketFactory;

public class TLSSocketFactory extends SSLSocketFactory {

    private static List<String> enabledProtocols;

    private SSLSocketFactory internalSSLSocketFactory;
    private String[] protocols;

    static {
        enabledProtocols = new ArrayList<>();
        if (Build.VERSION.SDK_INT <= Build.VERSION_CODES.KITKAT_WATCH) {
            enabledProtocols.add("TLSv1");
            enabledProtocols.add("TLSv1.1");
            enabledProtocols.add("TLSv1.2");
        } else if (Build.VERSION.SDK_INT <= Build.VERSION_CODES.P) {
            enabledProtocols.add("TLSv1.2");
        } else {
            enabledProtocols.add("TLSv1.2");
            enabledProtocols.add("TLSv1.3");
        }
    }

    public TLSSocketFactory() throws KeyManagementException, NoSuchAlgorithmException {
        SSLContext context = SSLContext.getInstance("TLS");
        context.init(null, null, null);
        internalSSLSocketFactory = context.getSocketFactory();

        List<String> supportedProtocols = Arrays.asList(context.getDefaultSSLParameters().getProtocols());
        List<String> protocols = new ArrayList<>(enabledProtocols);
        protocols.retainAll(supportedProtocols);
        this.protocols = protocols.toArray(new String[0]);
    }

    @Override
    public String[] getDefaultCipherSuites() {
        return internalSSLSocketFactory.getDefaultCipherSuites();
    }

    @Override
    public String[] getSupportedCipherSuites() {
        return internalSSLSocketFactory.getSupportedCipherSuites();
    }

    @Override
    public Socket createSocket() throws IOException {
        return enableTLSOnSocket(internalSSLSocketFactory.createSocket());
    }

    @Override
    public Socket createSocket(Socket s, String host, int port, boolean autoClose) throws IOException {
        return enableTLSOnSocket(internalSSLSocketFactory.createSocket(s, host, port, autoClose));
    }

    @Override
    public Socket createSocket(String host, int port) throws IOException, UnknownHostException {
        return enableTLSOnSocket(internalSSLSocketFactory.createSocket(host, port));
    }

    @Override
    public Socket createSocket(String host, int port, InetAddress localHost, int localPort)
        throws IOException, UnknownHostException {
        return enableTLSOnSocket(internalSSLSocketFactory.createSocket(host, port, localHost, localPort));
    }

    @Override
    public Socket createSocket(InetAddress host, int port) throws IOException {
        return enableTLSOnSocket(internalSSLSocketFactory.createSocket(host, port));
    }

    @Override
    public Socket createSocket(InetAddress address, int port, InetAddress localAddress, int localPort)
        throws IOException {
        return enableTLSOnSocket(internalSSLSocketFactory.createSocket(address, port, localAddress, localPort));
    }

    private Socket enableTLSOnSocket(Socket socket) {
        if ((socket instanceof SSLSocket) && protocols.length > 0) {
            ((SSLSocket) socket).setEnabledProtocols(protocols);
        }
        return socket;
    }
}
